package com.agri.system.service.impl;

import com.agri.common.utils.DateUtils;
import com.agri.system.domain.SysRollerParam;
import com.agri.system.domain.vo.RollerTermVO;
import com.agri.system.mapper.SysRollerParamMapper;
import com.agri.system.service.ISysRollerParamService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 卷膜参数配置Service业务层处理
 *
 * @author lld
 * @date 2026-02-27
 */
@Service
public class SysRollerParamServiceImpl extends ServiceImpl<SysRollerParamMapper, SysRollerParam> implements ISysRollerParamService
{

    /**
     * 查询卷膜参数配置
     *
     * @param id 卷膜参数配置主键
     * @return 卷膜参数配置
     */
    @Override
    public SysRollerParam selectSysRollerParamById(String id)
    {
        return baseMapper.selectSysRollerParamById(id);
    }

    /**
     * 查询卷膜参数配置列表
     *
     * @param sysRollerParam 卷膜参数配置
     * @return 卷膜参数配置
     */
    @Override
    public List<SysRollerParam> selectSysRollerParamList(SysRollerParam sysRollerParam)
    {
        return baseMapper.selectSysRollerParamList(sysRollerParam);
    }

    /**
     * 新增卷膜参数配置
     *
     * @param sysRollerParam 卷膜参数配置
     * @return 结果
     */
    @Override
    public int insertSysRollerParam(SysRollerParam sysRollerParam)
    {
        return baseMapper.insert(sysRollerParam);
    }

    /**
     * 修改卷膜参数配置
     *
     * @param sysRollerParam 卷膜参数配置
     * @return 结果
     */
    @Override
    public int updateSysRollerParam(SysRollerParam sysRollerParam)
    {
        sysRollerParam.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateSysRollerParam(sysRollerParam);
    }

    /**
     * 批量删除卷膜参数配置
     *
     * @param ids 需要删除的卷膜参数配置主键
     * @return 结果
     */
    @Override
    public int deleteSysRollerParamByIds(String[] ids)
    {
        return baseMapper.deleteSysRollerParamByIds(ids);
    }

    /**
     * 删除卷膜参数配置信息
     *
     * @param id 卷膜参数配置主键
     * @return 结果
     */
    @Override
    public int deleteSysRollerParamById(String id)
    {
        return baseMapper.deleteSysRollerParamById(id);
    }


    @Override
    public List<RollerTermVO> getRollerTerms(List<String> imeiList) {

        return baseMapper.getRollerTerms(imeiList);
    }
}
